@@ -31,6 +31,8 @@
   #define WINDOWS
 #endif
 
+#define ALBUFFERSIZE 1024*16
+
 class AudioEnv : public QObject
 {
 //	Q_OBJECT
@@ -44,7 +46,6 @@ public:
    void ListenerPosition (float c[4][4] );
    void UpdateObstruction (int);
    int LoadFile (const char *, bool);
-   int PlayFile (char *, bool);
    void SetSourcePosition (int, float *);
    void SetSourceVelocity (int, float *);
    void SetSourceGain (int handle, float gain);
@@ -56,8 +57,8 @@ public:
    int IncrementEnv();
 
 private:
-   ALuint buffer[512];
-   ALuint source[512];
+   ALuint buffer[ALBUFFERSIZE];
+   ALuint source[ALBUFFERSIZE];
    ALuint nextBuffer, nextSource;
    unsigned int EAXlevel;
    
