@@ -15,27 +15,28 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef CURSOR3D_H
-#define CURSOR3D_H
-
-/**
-  *@author Krippel Harald
-  */
-
-#include <QtGui>
-#include <plib/ssg.h>
-
 /**3D-Cursor for QCake
   *@author Krippel Harald
   */
 
-class cursor3d : public QCursor  {
+#ifndef CURSOR3D_H
+#define CURSOR3D_H
+
+#include <QtGui>
+#include <plib/ssg.h>
+
+
+//class cursor3d : public QCursor 
+class cursor3d : public  QObject
+{
+
+ Q_OBJECT
+
 public: 
-   cursor3d();
+   cursor3d(QObject *parent=0);
    ~cursor3d();
    void TurnOn();
    void TurnOff();
-   void update();
    void getPosition ( sgCoord  *cursorpos );
    int  Valid();
  
@@ -44,6 +45,9 @@ public:
     int y;
     int on;
 
+public slots:
+   void   update(float dt);
+
 protected:
     int valid;
 };
