@@ -19,25 +19,11 @@
   *@author Krippel Harald
   */
 
- #define QCAKEVERSION "QCake-Designer V0.6.3 [rev638]"
- 
- #define MAX_FIRE 10
+ #define QCAKEVERSION "QCake-Designer V0.7.0 [rev824]"
+
  #define MAX_FIRE_TRIS  200
  #define OBJ_OFF  -200000.0f
- #define MAX_PARTSYS 10
- #define MAX_WAVESYS 10   // dont touche see callback glcontrol !!!
- #define MAX_WSPEED 20.0f
  #define MAX_PLAYER 10
  #define MAX_PLAYER_OBJ 10
- #define MAX_BARRIER 20
- #define MAX_BARRIER_OBJ 1
- #define MAX_BODY 20
- #define MAX_BODY_OBJ 1
- #define MAX_SKY 1
- #define MAX_SPL 100
- #define MAX_QTSCRIPT 100
- #define MAX_SOUND 20
- #define MAX_SHADER 10
- #define MAX_CURSOR 10
  #define TIMER_INTERVAL 10
  #define DEFAULTSTARTID 4
