@@ -19,10 +19,13 @@
 #include <QPluginLoader>
 
 #include "mainwindow.hpp"
+#include "networkaccessmanager.hpp"
 #include "opmltree.hpp"
 #include "globdefines.h"
 #include "messages.hpp"
 #include "plugindialog.hpp"
+#include "signal.hpp"
+#include "capabilities.hpp"
 
 #include <CDefault.hpp>
 #include <CGlobalEdit.hpp>
@@ -41,6 +44,7 @@
 #include <CCursorEdit.hpp>
 #include <CSplEdit.hpp>
 #include <CSoundEdit.hpp>
+#include <CMediaEdit.hpp>
 #include <CGuitxtEdit.hpp>
 #include <CGuiinputEdit.hpp>
 #include <CGuibuttonEdit.hpp>
@@ -50,6 +54,8 @@
 #include <CProjectEdit.hpp>
 #include <CPrefEdit.hpp>
 
+NetworkAccessManager *MainWindow::s_networkAccessManager = 0;
+
 MainWindow::MainWindow()
 {
     tmpItem = NULL;
@@ -101,6 +107,9 @@ MainWindow::MainWindow()
     toolsPlayGroup->addAction(toolsPauseAct);
 
     modified=false;
+    modestop=false; 
+
+    connect(QCSignals::theInstance(), SIGNAL(scriptError()),this , SLOT(mode_stop()));
 }
 void MainWindow::closeEvent(QCloseEvent *event)
 {
@@ -127,9 +136,11 @@ void MainWindow::print()
 
 void MainWindow::preferences()
 {
-    CPrefEditDlg *dlg = new CPrefEditDlg(tr("Preferences"),this,g_editor);
+    CPrefEditDlg *dlg = new CPrefEditDlg(tr("Preferences"),this,g_editor,g_displayfps,g_displayphfps);
     if (dlg->exec() == QDialog::Accepted){
         g_editor = dlg->geteditpath();
+        g_displayfps = dlg->getfps();
+        g_displayphfps = dlg->getphfps();
         return;
     }
 
@@ -141,6 +152,8 @@ void MainWindow::readSettings()
     QSettings settings("QCake", "QCDesigner");
     QPoint pos = settings.value("mainwindow/pos", QPoint(200, 200)).toPoint();
     QSize size = settings.value("mainwindow/size", QSize(400, 400)).toSize();
+    g_displayfps = settings.value("mainwindow/displayfps", 1).toInt();
+    g_displayphfps = settings.value("mainwindow/displayphfps", 1).toInt();
     g_3dcatalogpath = settings.value("mainwindow/catalog", QString(QDir::homePath () + "/cat3d/")).toString();
     g_scriptcatalogpath = settings.value("mainwindow/scriptcatalogpath", QString(QDir::homePath () + "/splcat/")).toString();
     g_soundcatalogpath = settings.value("mainwindow/soundcatalogpath", QString(QDir::homePath () + "/soundcat/")).toString();
@@ -168,6 +181,8 @@ void MainWindow::writeSettings()
     QSettings settings("QCake", "QCDesigner");
     settings.setValue("mainwindow/pos", pos());
     settings.setValue("mainwindow/size", size());
+    settings.setValue("mainwindow/displayfps",g_displayfps);
+    settings.setValue("mainwindow/displayphfps",g_displayphfps);
     settings.setValue("mainwindow/catalog", g_3dcatalogpath);
     settings.setValue("mainwindow/scriptcatalogpath", g_scriptcatalogpath);
     settings.setValue("mainwindow/soundcatalogpath", g_soundcatalogpath);
@@ -177,6 +192,11 @@ void MainWindow::writeSettings()
     settings.setValue("mainwindow/editor", g_editor);
 }
 
+MainWindow::~MainWindow()
+{
+    delete s_networkAccessManager;
+}
+
 bool MainWindow::maybeSave()
 {
     if (modified) {
@@ -302,22 +322,22 @@ bool MainWindow::newProject()
 #ifdef    Q_OS_LINUX
          QString   copy = "cp -dpR \""+ g_apppath +"/data\" " +  g_prjpath ;
          qWarning( copy.toAscii() );   // debug
-         system (copy.toAscii());
+         system (copy.toAscii().constData());
 #endif
 #ifdef    Q_OS_IRIX
          QString   copy = "cp -DpR data " +  g_prjpath ;
          qWarning( copy.toAscii() );   // debug
-         system (copy.toAscii());
+         system (copy.toAscii().constData());
 #endif
 #ifdef    Q_OS_MACX
          QString   copy = "cp -pR data " +  g_prjpath ;
          qWarning( copy.toAscii() );
-         system (copy.toAscii());
+         system (copy.toAscii().constData());
 #endif
 #ifdef    Q_OS_WIN32
          QString   copy = "xcopy \""+ g_apppath +"/data\" \"" +  g_prjpath + "data\" /e /i" ;
          qWarning( copy.toAscii() );
-         system (copy.toAscii());
+         system (copy.toAscii().constData());
 #endif
          copy = "cp new.xml " +  g_prjpath + result + ".xml";  // debug
          qWarning( copy.toAscii() );                           // debug
@@ -365,6 +385,14 @@ void MainWindow::about()
   mb.exec();
 }
 
+void MainWindow::aboutCapabilities()
+{
+     Capabilities *window= new Capabilities();
+     window->show();
+     window->raise();
+     window->activateWindow();
+}
+
 void MainWindow::aboutPlugins()
 {
     PluginDialog dialog(pluginsDir.path(), pluginFileNames, this);
@@ -374,94 +402,111 @@ void MainWindow::aboutPlugins()
 void MainWindow::createActions()
 {
     fileNewAct = new QAction(QIcon(":/images/filenew.png"), tr("&New"), this);
-    fileNewAct->setShortcut(tr("Ctrl+N"));
+//    fileNewAct->setShortcut((tr("Ctrl+N"))); // did not work at the moment with QT4.3.4 
+    fileNewAct->setShortcut(QKeySequence("Ctrl+N"));
     fileNewAct->setStatusTip(tr("Create a new project"));
     connect(fileNewAct, SIGNAL(triggered()), this, SLOT(newProject()));
 
     fileOpenAct = new QAction(QIcon(":/images/fileopen.png"), tr("&Open ..."), this);
-    fileOpenAct->setShortcut(tr("Ctrl+O"));
+//    fileOpenAct->setShortcut(tr("Ctrl+O"));
+    fileOpenAct->setShortcut(QKeySequence("Ctrl+O"));
     fileOpenAct->setStatusTip(tr("Open a project"));
     connect(fileOpenAct, SIGNAL(triggered()), this, SLOT(open()));
 
     fileSaveAct = new QAction(QIcon(":/images/filesave.png"), tr("&Save"), this);
-    fileSaveAct->setShortcut(tr("Ctrl+S"));
+//    fileSaveAct->setShortcut(tr("Ctrl+S"));
+    fileSaveAct->setShortcut(QKeySequence("Ctrl+S"));
     fileSaveAct->setStatusTip(tr("Save the current project"));
     connect(fileSaveAct, SIGNAL(triggered()), this, SLOT(save()));
 
     filePrintAct = new QAction(QIcon(":/images/print.png"), tr("&Print ..."), this);
-    filePrintAct->setShortcut(tr("Ctrl+P"));
+//    filePrintAct->setShortcut(tr("Ctrl+P"));
+    filePrintAct->setShortcut(QKeySequence("Ctrl+P"));
     filePrintAct->setStatusTip(tr("Print the current ??"));
     connect(filePrintAct, SIGNAL(triggered()), this, SLOT(print()));
 
 //    filePrefAct = new QAction(QIcon(":/images/print.png"), tr("&Preferences ..."), this);
     filePrefAct = new QAction(tr("&Preferences ..."), this);
-    filePrefAct->setShortcut(tr("Ctrl+F"));
+//    filePrefAct->setShortcut(tr("Ctrl+F"));
+    filePrefAct->setShortcut(QKeySequence("Ctrl+F"));
     filePrefAct->setStatusTip(tr("Preferences"));
     connect(filePrefAct, SIGNAL(triggered()), this, SLOT(preferences()));
 
     editUndoAct = new QAction(QIcon(":/images/undo.png"), tr("&Undo"), this);
-    editUndoAct->setShortcut(tr("Ctrl+Z"));
+//    editUndoAct->setShortcut(tr("Ctrl+Z"));
+    editUndoAct->setShortcut(QKeySequence("Ctrl+Z"));
     editUndoAct->setStatusTip(tr("Undo the last editing action"));
     connect(editUndoAct, SIGNAL(triggered()), this, SLOT(undo()));
 
     editCutAct = new QAction(tr("&Cut"), this);
-    editCutAct->setShortcut(tr("Ctrl+C"));
+//    editCutAct->setShortcut(tr("Ctrl+C"));
+    editCutAct->setShortcut(QKeySequence("Ctrl+C"));
     editCutAct->setStatusTip(tr("Cut the selected item"));
     connect(editCutAct, SIGNAL(triggered()), this, SLOT(cut()));
 
     fileQuitAct = new QAction(tr("&Quit"), this);
-    fileQuitAct->setShortcut(tr("Ctrl+Q"));
+//    fileQuitAct->setShortcut(QKeySequence(tr("Ctrl+Q")));
+//    fileQuitAct->setShortcut(tr("Ctrl+Q", "Quit"));
+    fileQuitAct->setShortcut(QKeySequence("Ctrl+Q"));
     fileQuitAct->setStatusTip(tr("Quit the application"));
     connect(fileQuitAct, SIGNAL(triggered()), this, SLOT(close()));
 
     viewFullScreenAct = new QAction(tr("&FullScreen"), this);
-    viewFullScreenAct->setShortcut(tr("Ctrl+F"));
+//    viewFullScreenAct->setShortcut(tr("Ctrl+F"));
     viewFullScreenAct->setStatusTip(tr("full screen view"));
     connect(viewFullScreenAct, SIGNAL(triggered()), this, SLOT(slotFullScreen()));
 
     viewFrontScreenAct = new QAction(tr("&FrontView"), this);
-    viewFrontScreenAct->setShortcut(tr("Ctrl+2"));
+//    viewFrontScreenAct->setShortcut(tr("Ctrl+2"));
+    viewFrontScreenAct->setShortcut(QKeySequence("Ctrl+2"));
     viewFrontScreenAct->setStatusTip(tr("fornt view"));
     connect(viewFrontScreenAct, SIGNAL(triggered()), this, SLOT(slotFrontView()));
 
     toolsEditCamAct = new QAction(QIcon(":/images/wizard.png"),tr("&EditCam"), this);
-    toolsEditCamAct->setShortcut(tr("Ctrl+K"));
+//    toolsEditCamAct->setShortcut(tr("Ctrl+K"));
+    toolsEditCamAct->setShortcut(QKeySequence("Ctrl+K"));
     toolsEditCamAct->setStatusTip(tr("EditorCamera"));
     toolsEditCamAct->setWhatsThis(tr("Editor Camera\n\nmove around"));
     connect(toolsEditCamAct, SIGNAL(triggered()), this, SLOT(slotToolsEditCam()));
 
     toolsTranslateAct = new QAction(QIcon(":/images/move.png"),tr("&Translate"), this);
-    toolsTranslateAct->setShortcut(tr("Ctrl+T"));
+//    toolsTranslateAct->setShortcut(tr("Ctrl+T"));
+    toolsTranslateAct->setShortcut(QKeySequence("Ctrl+T"));
     toolsTranslateAct->setStatusTip(tr("Translate"));
     toolsTranslateAct->setWhatsThis(tr("Translate\n\nTranslate Object"));
     connect(toolsTranslateAct, SIGNAL(triggered()), this, SLOT(slotToolsTranslate()));
 
     toolsRotateAct = new QAction(QIcon(":/images/rotate.png"), tr("&Rotate"), this);
-    toolsRotateAct->setShortcut(tr("Ctrl+R"));
+//    toolsRotateAct->setShortcut(tr("Ctrl+R"));
+    toolsRotateAct->setShortcut(QKeySequence("Ctrl+R"));
     toolsRotateAct->setStatusTip(tr("Rotate"));
     toolsRotateAct->setWhatsThis(tr("Rotate\n\nRotate Object"));
     connect(toolsRotateAct, SIGNAL(triggered()), this, SLOT(slotToolsRotate()));
 
     toolsScaleAct = new QAction(QIcon(":/images/crop.png"), tr("&Scale"), this);
-    toolsScaleAct->setShortcut(tr("Ctrl+A"));
+//    toolsScaleAct->setShortcut(tr("Ctrl+A"));
+    toolsScaleAct->setShortcut(QKeySequence("Ctrl+A"));
     toolsScaleAct->setStatusTip(tr("Scale"));
     toolsScaleAct->setWhatsThis(tr("Scale\n\nScale Object"));
     connect(toolsScaleAct, SIGNAL(triggered()), this, SLOT(slotToolsScale()));
 
     toolsPlayAct = new QAction(QIcon(":/images/run.png"), tr("&Play"), this);
-    toolsPlayAct->setShortcut(tr("Ctrl+P"));
+//    toolsPlayAct->setShortcut(tr("Ctrl+P"));
+    toolsPlayAct->setShortcut(QKeySequence("Ctrl+P"));
     toolsPlayAct->setStatusTip(tr("Play"));
     toolsPlayAct->setWhatsThis(tr("Play\n\nswitch to Play mode"));
     connect(toolsPlayAct, SIGNAL(triggered()), this, SLOT(slotToolsPlay()));
 
     toolsPauseAct = new QAction(QIcon(":/images/redo.png"), tr("&Pause"), this);
-    toolsPauseAct->setShortcut(tr("Ctrl+O"));
+//    toolsPauseAct->setShortcut(tr("Ctrl+O"));
+    toolsPauseAct->setShortcut(QKeySequence("Ctrl+O"));
     toolsPauseAct->setStatusTip(tr("Pause"));
     toolsPauseAct->setWhatsThis(tr("Pause\n\nswitch to Pause mode"));
     connect(toolsPauseAct, SIGNAL(triggered()), this, SLOT(slotToolsPause()));
 
     toolsStopAct = new QAction(QIcon(":/images/stop.png"), tr("&Stop"), this);
-    toolsStopAct->setShortcut(tr("Ctrl+X"));
+//    toolsStopAct->setShortcut(tr("Ctrl+X"));
+    toolsStopAct->setShortcut(QKeySequence("Ctrl+X"));
     toolsStopAct->setStatusTip(tr("Stop"));
     toolsStopAct->setWhatsThis(tr("Stop\n\nswitch to Stop mode"));
     connect(toolsStopAct, SIGNAL(triggered()), this, SLOT(slotToolsStop()));
@@ -478,8 +523,11 @@ void MainWindow::createActions()
     aboutPluginsAct = new QAction(tr("About &Plugins"), this);
     aboutPluginsAct->setStatusTip(tr("Show the loaded Plugins"));
     connect(aboutPluginsAct, SIGNAL(triggered()), this, SLOT(aboutPlugins()));
-
     
+    aboutCapabilitiesAct = new QAction(tr("About &Capabilities"), this);
+    aboutCapabilitiesAct->setStatusTip(tr("Show the Capabilities"));
+    connect(aboutCapabilitiesAct, SIGNAL(triggered()), this, SLOT(aboutCapabilities()));
+
     for (int i = 0; i < MaxRecentFiles; ++i) {
         recentFileActs[i] = new QAction(this);
         recentFileActs[i]->setVisible(false);
@@ -525,6 +573,7 @@ void MainWindow::createMenus()
     helpMenu->addAction(helpAboutAppAct);
     helpMenu->addAction(helpaboutQtAct);
     helpMenu->addAction(aboutPluginsAct);
+    helpMenu->addAction(aboutCapabilitiesAct);
 }
 
 void MainWindow::createToolBars()
@@ -580,6 +629,7 @@ void MainWindow::createDockWindows()
     CCursorEditDlg *CursorEdit = new CCursorEditDlg("CursorEdit",this,0);
     CSplEditDlg *SplEdit = new CSplEditDlg("SplEdit",this,0);
     CSoundEditDlg *SoundEdit = new CSoundEditDlg("SoundEdit",this,0);
+    CMediaEditDlg *MediaEdit = new CMediaEditDlg("MediaEdit",this,0);
     CGUITextEditDlg *GUITextEdit = new CGUITextEditDlg("GUITextEdit",this,0);
     CGUIInputEditDlg *GUIInputEdit = new CGUIInputEditDlg("GUIInputEdit",this,0);
     CGUIButtonEditDlg *GUIButtonEdit = new CGUIButtonEditDlg("GUIButtonEdit",this,0);
@@ -614,6 +664,7 @@ void MainWindow::createDockWindows()
     stack->addWidget(GUIOSButtonEdit);  // 20
     stack->addWidget(NetworkEdit);  // 21
     stack->addWidget(SceneEdit);  // 22
+    stack->addWidget(MediaEdit);  // 23 
     // hash
     stackNameForItem.insert("DEFAULT",0);
     stackNameForItem.insert("GLOBAL",1);
@@ -632,7 +683,9 @@ void MainWindow::createDockWindows()
     stackNameForItem.insert("CURSOR",14);
     stackNameForItem.insert("SPL",15);
     stackNameForItem.insert("JS",15);
+    stackNameForItem.insert("PYTHON",15);
     stackNameForItem.insert("SOUND",16);
+    stackNameForItem.insert("MEDIA",23);
     stackNameForItem.insert("GUI-TXT",17);
     stackNameForItem.insert("GUI-INPUT",18);
     stackNameForItem.insert("GUI-BUTTON",19);
@@ -709,6 +762,7 @@ QString MainWindow::strippedName(const QString &fullFileName)
 
 void MainWindow::opmlitemClicked(QTreeWidgetItem *item, int column)
 {
+    Q_UNUSED(column);
     modified = true;
     FolderListItem *i = (FolderListItem *) item;
     ((CQcakeDlg*)stack->widget(stackNameForItem[i->text(1)]))->slotGetData(i);
@@ -775,16 +829,18 @@ void MainWindow::slotToolsScale()
 
 void MainWindow::slotToolsPlay()
 {
+  modestop = false;
   g_messages->clear();
-  if(g_gl->compile()){
-      slotToolsStop();
-      return;
+  g_gl->compile();
+
+  if( modestop == false ){
+    g_playmode = 1;
+    g_keyset.clear();
+    toolsPlayAct->setChecked(true);
+    g_gl->setFocus ();
+    QString qmsg ="Play\n";
+    ErrorMsg errormsg(qmsg);
   }
-  g_playmode = 1;
-  toolsPlayAct->setChecked(true);
-  g_gl->setFocus ();
-  QString qmsg ="Play\n";
-  ErrorMsg errormsg(qmsg);
 }
 
 void MainWindow::slotToolsPause()
@@ -847,6 +903,7 @@ void MainWindow::loadPlugins()
 
 void MainWindow::populateMenus(QObject *plugin)
 {
+    Q_UNUSED(plugin);
 /*
     BrushInterface *iBrush = qobject_cast<BrushInterface *>(plugin);
     if (iBrush)
@@ -878,3 +935,17 @@ void MainWindow::addToMenu(QObject *plugin, const QStringList &texts,
         }
     }
 }
+
+void MainWindow::mode_stop()
+{
+    modestop = true;
+    slotToolsStop();
+}
+
+NetworkAccessManager *MainWindow::networkAccessManager()
+{
+    if (!s_networkAccessManager) {
+        s_networkAccessManager = new NetworkAccessManager();
+    }
+    return s_networkAccessManager;
+}
