@@ -24,7 +24,7 @@ class scriptPrg: public QObject
 {
 Q_OBJECT
 public:
-    scriptPrg(QObject *parent = 0);
+    scriptPrg(QObject *parent=0);
     virtual int compile(void);
     virtual int run(void);
     virtual void update(void);
@@ -34,10 +34,12 @@ public:
 
 public slots:
     void slot_update(const QString &);
+    void slot_compile(void);
+    void slot_run(void);
 
 protected:
   int on;
-
+  int enable;
 };
 
 #endif
