@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri Jan 21 2005
     copyright            : (C) 2005 by Harald Krippel
-    email                : neuro.harald@surfeu.at
+    email                : harald@hte-develop.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,7 +21,6 @@
 #include "scriptprg.hpp"
 #include "messages.hpp"
 
-
 void spl_qt_reportfunc(int type, void *desc, const char *fmt, ...)
 {
     va_list ap;
@@ -44,7 +43,7 @@ static void *qcakespl_malloc_file(const char *filename, int *size)
       return spl_malloc_file(filename,size);
    }else{
       QString qcfileName = g_prjpath + "/" +filename;
-      return spl_malloc_file(qcfileName.toAscii(),size);
+      return spl_malloc_file(qcfileName.toAscii().constData(),size);
    }
 }
 
@@ -177,7 +176,7 @@ static struct spl_node *my_addRelForce ( struct spl_task *task, void *data )
 static struct spl_node *my_setSequence ( struct spl_task *task, void *data )
 {
   if ( spl_clib_get_argc(task) != 3 ){
-    spl_report(SPL_REPORT_RUNTIME, task,"setLinVel: Parameter must be a int, int, int!\n" ) ;
+    spl_report(SPL_REPORT_RUNTIME, task,"setSequence: Parameter must be a int, int, int!\n" ) ;
     ((splPrg *)data)->TurnOff();
     return 0 ;
   } else {
@@ -230,7 +229,7 @@ static struct spl_node *my_setRotation ( struct spl_task *task, void *data )
 static struct spl_node *my_Rotation ( struct spl_task *task, void *data )
 {
   if ( spl_clib_get_argc(task) != 4 ){
-    spl_report(SPL_REPORT_RUNTIME, task,"setRotation: Parameter must be a int, float, float, float !\n" ) ;
+    spl_report(SPL_REPORT_RUNTIME, task,"Rotation: Parameter must be a int, float, float, float !\n" ) ;
     ((splPrg *)data)->TurnOff();
     return 0 ;
   } else {
@@ -344,7 +343,7 @@ static struct spl_node *my_getAttribute ( struct spl_task *task, void *data )
   } else {
     int     hh=spl_clib_get_int(task);
     char *attr=spl_clib_get_string(task);
-    return SPL_NEW_STRING_DUP(((splPrg *)data)->ScriptApi->getAttribute ( hh, attr ).toAscii().data() ) ;
+    return SPL_NEW_STRING_DUP(((splPrg *)data)->ScriptApi->getAttribute ( hh, attr ).toAscii().constData() ) ;
   }
 }
 
@@ -373,6 +372,17 @@ static struct spl_node *my_getKey ( struct spl_task *task, void *data )
   }
 }
 
+static struct spl_node *my_keyPressed ( struct spl_task *task, void *data )
+{
+  if ( spl_clib_get_argc(task) != 1 ){
+    spl_report(SPL_REPORT_RUNTIME, task,"keyPressed: Parameter must be a single int!\n" ) ;
+    ((splPrg *)data)->TurnOff();
+    return 0 ;
+  } else {
+    return SPL_NEW_INT(((splPrg *)data)->ScriptApi->keyPressed (spl_clib_get_int(task) ) ) ;
+  }
+}
+
 static struct spl_node *my_switchScene ( struct spl_task *task, void *data )
 {
   if ( spl_clib_get_argc(task) != 1 ){
@@ -477,7 +487,7 @@ static struct spl_node *my_astarReadPathY ( struct spl_task *task, void *data )
 static struct spl_node *my_astarReadMap ( struct spl_task *task, void *data )
 {
   if ( spl_clib_get_argc(task) != 1 ){
-    spl_report(SPL_REPORT_RUNTIME, task,"astarReadPathY: Parameter must be a string !\n" ) ;
+    spl_report(SPL_REPORT_RUNTIME, task,"astarReadMap: Parameter must be a string !\n" ) ;
     ((splPrg *)data)->TurnOff();
     return 0 ;
   } else {
@@ -490,7 +500,7 @@ static struct spl_node *my_astarReadMap ( struct spl_task *task, void *data )
 static struct spl_node *my_astarReadMapValue ( struct spl_task *task, void *data )
 {
   if ( spl_clib_get_argc(task) != 2 ){
-    spl_report(SPL_REPORT_RUNTIME, task,"astarReadPathY: Parameter must be a int int !\n" ) ;
+    spl_report(SPL_REPORT_RUNTIME, task,"astarReadMapValue: Parameter must be a int int !\n" ) ;
     ((splPrg *)data)->TurnOff();
     return 0 ;
   } else {
@@ -504,7 +514,7 @@ static struct spl_node *my_astarReadMapValue ( struct spl_task *task, void *data
 static struct spl_node *my_astarInit ( struct spl_task *task, void *data )
 {
   if ( spl_clib_get_argc(task) != 4 ){
-    spl_report(SPL_REPORT_RUNTIME, task,"astarReadPathY: Parameter must be a int int int int !\n" ) ;
+    spl_report(SPL_REPORT_RUNTIME, task,"astarInit: Parameter must be a int int int int !\n" ) ;
     ((splPrg *)data)->TurnOff();
     return 0 ;
   } else {
@@ -536,12 +546,11 @@ static struct spl_node *my_tmpobjInit ( struct spl_task *task, void *data )
   }
 }
 
-//****************************************************************
- 
- splPrg::splPrg(const char *prg):scriptPrg()
+//**************************************************************** 
+splPrg::splPrg(const char *prg)
+:scriptPrg()
  {
      ScriptApi=QcakeScriptApi::theInstance();
-     item = NULL;
      strcpy(prgname,prg);
      strcpy(prgsrc,prg);
      vm = spl_vm_create();
@@ -555,7 +564,7 @@ static struct spl_node *my_tmpobjInit ( struct spl_task *task, void *data )
 #endif
 
      QString  vmpath = QString(".:./spl_modules:%1").arg(spl_system_modules_dir());
-     vm->path = strdup(vmpath.toAscii().data());
+     vm->path = strdup(vmpath.toAscii().constData());
      task = spl_task_create(vm, 0);
 
      // register the language qcake routines
@@ -582,7 +591,7 @@ static struct spl_node *my_tmpobjInit ( struct spl_task *task, void *data )
      spl_clib_reg(vm, (char *)"getAttribute" , my_getAttribute,  this);
      spl_clib_reg(vm, (char *)"setAttribute" , my_setAttribute,  this);
      spl_clib_reg(vm, (char *)"getKey"       , my_getKey      ,  this);
-     spl_clib_reg(vm, (char *)"switchScene"  , my_switchScene ,  this);
+     spl_clib_reg(vm, (char *)"keyPressed"       , my_keyPressed      ,  this);     spl_clib_reg(vm, (char *)"switchScene"  , my_switchScene ,  this);
      spl_clib_reg(vm, (char *)"playSound"    , my_playSound   ,  this);
      spl_clib_reg(vm, (char *)"stopSound"    , my_stopSound   ,  this);
      spl_clib_reg(vm, (char *)"switchCamera" , my_switchCamera,  this);
@@ -596,8 +605,9 @@ static struct spl_node *my_tmpobjInit ( struct spl_task *task, void *data )
      spl_clib_reg(vm, (char *)"tmpobjInit"   , my_tmpobjInit  ,  this);
     
      // load the standard spl qcake library
-     QString spl_stdlib_file = g_apppath + "/spl_stdlib.spl";
-     char *spl_stdlib_code = (char *)spl_malloc_file(spl_stdlib_file.toAscii().data(), 0);
+     QString spl_stdlib_file = g_prjpath + "/data/spl_stdlib.spl";
+     qDebug() << spl_stdlib_file;
+     char *spl_stdlib_code = (char *)spl_malloc_file(spl_stdlib_file.toAscii().constData(), 0);
      assert(spl_stdlib_code != NULL);
      spl_eval(vm, 0, strdup("stdlib"), spl_stdlib_code);
      free(spl_stdlib_code);
@@ -623,12 +633,22 @@ static struct spl_node *my_tmpobjInit ( struct spl_task *task, void *data )
 
  void splPrg::update(void)
  {
+#ifdef Q_OS_UNIX
+  // set locale plib problem
+  char * ctype = qstrdup(setlocale(LC_NUMERIC, 0));
+  setlocale(LC_NUMERIC, "C");        // make sprintf()/scanf() work
+#endif
   while ( task && task->code && on==1 && g_playmode==1)
   {
    spl_gc_maybe(vm);
    task = spl_schedule(task); 
    if(spl_exec(task)) break;
   }
+#ifdef Q_OS_UNIX
+     // restore locale plib problem
+     setlocale(LC_NUMERIC, ctype);
+     delete [] ctype ;
+#endif
  }
 
  splPrg::~splPrg()
